#
# This script was written by Michel Arboi <arboi@bigfoot.com>
#
# GPL...
#
# SMTP is defined by RFC 821. Messages are defined by RFC 822
#
# Here is the EICAR test string : {
# X5O!P%@AP[4\PZX54(P^)7CC)7}$EICAR-STANDARD-ANTIVIRUS-TEST-FILE!$H+H*
# You can get it at http://www.eicar.org/anti_virus_test_file.htm
#

if(description)
{
 script_id(11034);
 script_version ("$Revision: 1.6 $");
 name["english"] = "SMTP antivirus filter";
 script_name(english:name["english"]);
 
 desc["english"] = "
This script sends messages with the EICAR test string in
them to the mail server. If there is an antivirus filter, they should
be blocked or removed.

Solution: Install an antivirus / upgrade it

Risk factor : Low";

 script_description(english:desc["english"]);
 
 summary["english"] = "Test a SMTP antivirus filter";
 script_summary(english:summary["english"]);
 
 script_category(ACT_ATTACK);
 
 script_copyright(english:"This script is Copyright (C) 2002 Michel Arboi");
 family["english"] = "Firewalls";
 script_family(english:family["english"]);

 script_dependencie("find_service.nes", "smtp_settings.nasl");
 script_require_ports("Services/smtp", 25);

 #
 exit(0);
}

#
# The script code starts here
#

include("smtp_func.inc");

#

n_sent = 0;

fromaddr = smtp_from_header();
toaddr = smtp_to_header();

port = get_kb_item("Services/smtp");
if (!port) port = 25;

s = open_sock_tcp(port);
if (!s) exit(0);

send(socket: s, data: string("HELO nessus\r\n"));
buff = recv(socket:s, length:2048);

# MIME attachment

header = string("From: ", fromaddr, "\r\nTo: ", toaddr, "\r\n",
	"Organization: Nessus kabale\r\nMIME-Version: 1.0\r\n");

doublequote=raw_string(0x22);

msg="Subject: Nessus antivirus test 1: base64 attachment
Content-Type: multipart/mixed; boundary=<QQ>=-=-=<QQ>
Lines: 13


--=-=-=

If you can read or execute the attachment, this means that you do not
have an antivirus, or that it was disabled.

--=-=-=
Content-Type: application/octet-stream
Content-Disposition: attachment; filename=eicar.com
Content-Description: EICAR test file

X5O!P%@AP[4\PZX54(P^)7CC)7}$EICAR-STANDARD-ANTIVIRUS-TEST-FILE!$H+H*
--=-=-=--

";

msg = ereg_replace(pattern:"<QQ>", string:msg, replace:doublequote);

n=smtp_send_socket(socket:s, from: fromaddr, to: toaddr, body: header+msg);
n_sent=n_sent+n;

# uuencode

msg = "Subject: Nessus antivirus test 2: uuencoded attachment
Lines: 9

If you can read or execute the attachement, you need to install an
antivirus or fix your current one.

begin 664 eicar.com
M6#5/(5`E0$%06S1<4%I8-30H4%XI-T-#*3=])$5)0T%2+5-404Y$05)$+4%.
75$E625)54RU415-4+49)3$4A)$@K2<QQ>H`
`
end
";

msg = ereg_replace(pattern:"<QQ>", string:msg, replace:doublequote);

n=smtp_send_socket(socket:s, from: fromaddr, to: toaddr, body: header+msg);
n_sent=n_sent+n;

# TBD: broken MIME attachment - Cf. Bugtraq archives

# Close & quit

send(socket: s, data: string("QUIT\r\n"));
close(s);
if (n_sent == 0) {
  security_note(port: port, 
	data: "For some reason, we could not send the EICAR test string to this MTA");
} 
if (n_sent > 0) {
  security_note(port: port, 
	data:string(	"The EICAR test string was sent ", n_sent, 
			" times. Check your mailbox!")); 
}

